is_email: Check if an argument is an email address string

View source: R/string.R

is_emailR Documentation

Check if an argument is an email address string

Description

Check if an argument is an email address string

Usage

is_email(x)

Arguments

x

(any)
Object to check.

Value

TRUE if x is a valid email address string, FALSE otherwise.

Examples

is_email("user@example.com")

checkstring documentation built on Sept. 28, 2026, 5:07 p.m.