Validates the type/subtype format where the top-level type must be one of the IANA-registered
types: application, audio, font, image, message, model, multipart, text, or
video.
Validates the type/subtype format where the top-level type must be one of the IANA-registered
types: application, audio, font, image, message, model, multipart, text, or
video.