Skip to contents

Check if an argument is a email address string

Usage

is_email(x)

Arguments

x

(any)
Object to check.

Value

TRUE if x is a valid email address string, FALSE otherwise.

Examples

is_email("user@example.com")
#> [1] TRUE