R/string.R
is_email.Rd
Check if an argument is a email address string
is_email(x)
(any) Object to check.
any
TRUE if x is a valid email address string, FALSE otherwise.
TRUE
x
FALSE
is_email("user@example.com") #> [1] TRUE