| is_email | R Documentation |
Check if an argument is an email address string
is_email(x)
x |
( |
TRUE if x is a valid email address string, FALSE otherwise.
is_email("user@example.com")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.